@@ -108,6 +108,7 @@ class MSLowApi:
                           limit: int = None,
                           offset: int = None,
                           search: Search = None,
+                          orders: Order = None,
                           filters: Filter = None,
                           expand: Expand = None, **kwargs):
         params = []
@@ -119,6 +120,8 @@ class MSLowApi:
             params.append(str(search))
         if filters is not None:
             params.append(str(filters))
+        if orders is not None:
+            params.append(str(orders))
         if expand is not None:
             params.append(str(expand))
         params_str = ""
